import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getZdwrqysc() {
    let interfaceName = "重点污染企业生产";
    let {pollutingEnterprises, productionByPollutingEnterprises, pollutingType, pollutingEnterprisesTOP10, comparisonOfPollutionTypesIndex, industryTypePollutantEnterprise, pollutingCompaniesScatter} = await getInterfaceByInterfaceName(interfaceName);
    
    // ------------------test----------------
    // let pollutingEnterprises:any = {"numPollutingEnterprises":48};
    // let productionByPollutingEnterprises:any = {};
    // let pollutingType:any = {};
    // let pollutingCompaniesScatter = [{"townName":"白鹤镇","latitudeAndLongitude":[],"details":"白鹤镇， 重点污染企业0家。"},{"townName":"香花桥街道","latitudeAndLongitude":[],"details":"香花桥街道， 重点污染企业0家。"},{"townName":"重固镇","latitudeAndLongitude":[],"details":"重固镇， 重点污染企业0家。"},{"townName":"华新镇","latitudeAndLongitude":[],"details":"华新镇， 重点污染企业0家。"},{"townName":"赵巷镇 ","latitudeAndLongitude":[],"details":"赵巷镇 ， 重点污染企业0家。"},{"townName":"徐泾镇","latitudeAndLongitude":[],"details":"徐泾镇， 重点污染企业0家。"},{"townName":"盈浦街道","latitudeAndLongitude":[],"details":"盈浦街道， 重点污染企业0家。"},{"townName":"夏阳街道","latitudeAndLongitude":[],"details":"夏阳街道， 重点污染企业0家。"},{"townName":"朱家角镇","latitudeAndLongitude":[],"details":"朱家角镇， 重点污染企业0家。"},{"townName":"金泽镇","latitudeAndLongitude":[],"details":"金泽镇， 重点污染企业0家。"},{"townName":"练塘镇","latitudeAndLongitude":[],"details":"练塘镇， 重点污染企业0家。"}];
    // let pollutingEnterprisesTOP10 = [{companyName:"上海山崎电路板有限公司", value:"2.24"},{companyName:"上海山崎电路板上海朱家角污水处理工程建设有限公司", value:"1.52"}];
    // let comparisonOfPollutionTypesIndex = [{"pollutionType":"大气污染","numberOfPollutingCompanies":0,"productionIndex":0.00},{"pollutionType":"土壤污染","numberOfPollutingCompanies":0,"productionIndex":0.00},{"pollutionType":"水污染","numberOfPollutingCompanies":0,"productionIndex":0.00},{"pollutionType":"危险废物","numberOfPollutingCompanies":0,"productionIndex":0.00},{"pollutionType":"其他","numberOfPollutingCompanies":0,"productionIndex":0.00}];
    // let industryTypePollutantEnterprise = [{"industryType":"电力行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"电子行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"纺织行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"机械行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"批发和零售业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"汽车行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"轻工行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"石化行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"水煤燃气","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"医药行业","numberOfPollutingCompanies":0,"productionIndex":0.00},{"industryType":"有色行业","numberOfPollutingCompanies":0,"productionIndex":0.00}];
    // -----------------end-------------------

    if (JSON.stringify(pollutingEnterprises) === '{}') pollutingEnterprises = {numPollutingEnterprises:0};
    if (JSON.stringify(productionByPollutingEnterprises) === '{}') productionByPollutingEnterprises = {pollutingEnterprisesIndex:0};
    if (JSON.stringify(pollutingType) === '{}') pollutingType = {waterPollution:0, hazardousWaste:0, airPollution:0, soilPollution:0, otherHighlights:0};

    if (!pollutingEnterprises) throw new BizError(`${interfaceName} 缺少参数 pollutingEnterprises` );
    if (!productionByPollutingEnterprises) throw new BizError(`${interfaceName} 缺少参数 productionByPollutingEnterprises` );
    if (!pollutingType) throw new BizError(`${interfaceName} 缺少参数 pollutingType` );
    if (!pollutingEnterprisesTOP10) throw new BizError(`${interfaceName} 缺少参数 pollutingEnterprisesTOP10` );
    if (!comparisonOfPollutionTypesIndex) throw new BizError(`${interfaceName} 缺少参数 comparisonOfPollutionTypesIndex` );
    if (!industryTypePollutantEnterprise) throw new BizError(`${interfaceName} 缺少参数 industryTypePollutantEnterprise` );
    if (!pollutingCompaniesScatter) throw new BizError(`${interfaceName} 缺少参数 pollutingCompaniesScatter` );

    //污染企业数据
    let pollutingInfo = {污染企业总数: pollutingEnterprises.numPollutingEnterprises};

    //污染企业生产数据
    let productionInfo = {污染企业生产指数: productionByPollutingEnterprises.pollutingEnterprisesIndex};

    //污染类型
    let {waterPollution, hazardousWaste, airPollution, soilPollution, otherHighlights} = pollutingType;
    let pollutingTypeInfo = {
        水污染: waterPollution,
        危险污染: hazardousWaste,
        大气污染: airPollution,
        土壤污染: soilPollution,
        其他重点: otherHighlights    
    };

    //污染企业TOP10
    let pollutingTop10 = {};
    pollutingEnterprisesTOP10.forEach( info => {
        let {companyName, value} = info;
        pollutingTop10[companyName] = value;
    })

    //各污染类型企业生产指数对比
    let pollutionTypeInfo;
    let numberOfPollutingCompaniesData = {};
    let productionIndexData = {};
    comparisonOfPollutionTypesIndex.forEach( info => {
        let {pollutionType, numberOfPollutingCompanies, productionIndex} = info;
        numberOfPollutingCompaniesData[pollutionType] = numberOfPollutingCompanies;
        productionIndexData[pollutionType] = productionIndex;
    })
    pollutionTypeInfo = {污染企业数: numberOfPollutingCompaniesData, 生产指数: productionIndexData};

    //各行业类型污染企业生产指数对比
    let industryTypeInfo;
    let numberOfPollutingData = {};
    let productionData = {};
    industryTypePollutantEnterprise.forEach( info => {
        let {industryType, numberOfPollutingCompanies, productionIndex} = info;
        numberOfPollutingData[industryType] = numberOfPollutingCompanies;
        productionData[industryType] = productionIndex;
    })
    industryTypeInfo = {污染企业数: numberOfPollutingData, 生产指数: productionData};

    return {pollutingInfo, productionInfo, pollutingTypeInfo, pollutionTypeInfo, pollutingTop10, industryTypeInfo, pollutingCompaniesScatter}
}